#!/bin/sh

_SAMPLE_DIR_=`dirname "$0"`
_YH_="$_SAMPLE_DIR_/../.."

if [ "`uname -a | grep HP-UX`" ] ; then
  JAVA_EXE="/opt/java6/bin/java"
elif [ "`uname | grep SunOS`" ] ; then
  JAVA_EXE="/usr/jdk/instances/jdk1.6.0/bin/java"
elif [ "`uname -a | grep Linux`" ] && [ "`uname -i | grep x86_64`" ] ; then
  JAVA_EXE="$_YH_/jre64/bin/java"
elif [ "`uname -a | grep Linux`" ] && [ "`uname -i | grep i386`" ] ; then
  JAVA_EXE="$_YH_/jre/bin/java"
fi

if [ ! -r "$JAVA_EXE" ] && [ ! -z "$JAVA_HOME" ] ; then
  JAVA_EXE="$JAVA_HOME/bin/java"
fi

if [ ! -r "$JAVA_EXE" ] ; then
  JAVA_EXE=/usr/bin/java
fi

# Check Java version
JAVA6=`$JAVA_EXE -version 2>&1 | grep 1.6`
JAVA7=`$JAVA_EXE -version 2>&1 | grep 1.7`
if [ -z "$JAVA6" ] && [ -z "$JAVA7" ] ; then
  echo "This example requires Java 6 or newer; specify appropriate Java via JAVA_HOME or PATH or edit this script ($0) explicitly"
  exit
fi

# Set AGENT_PATH to system-dependent path to the profiler agent library
if [ "`uname -a | grep Linux`" ] ; then
  if [ "`uname -i | grep arm`" ] ; then
    # ARM: detect whether it is a hard- or a soft-float point
    if [ "`readelf -A $JAVA_EXE | grep 'Tag_ABI_VFP_args: VFP registers'`" ] ; then
      AGENT_PATH="$_YH_/bin/linux-armv7-hf/libyjpagent.so"
    elif [ "`cat /proc/cpuinfo | grep ARMv7`" ] ; then
      AGENT_PATH="$_YH_/bin/linux-armv7-sf/libyjpagent.so"
    else
      AGENT_PATH="$_YH_/bin/linux-armv5-sf/libyjpagent.so"
    fi
  elif [ "`uname -i | grep ppc`" ] ; then
    if [ "`$JAVA_EXE -version 2>&1 | grep ppc64`" ] ; then
      AGENT_PATH="$_YH_/bin/linux-ppc-64/libyjpagent.so"
    else
      AGENT_PATH="$_YH_/bin/linux-ppc-32/libyjpagent.so"
    fi
  elif [ "`uname -i | grep x86_64`" ] ; then
    # We assume that 64-bit Java is used on Linux AMD 64; otherwise change "64" with "32" in the path.
    AGENT_PATH="$_YH_/bin/linux-x86-64/libyjpagent.so"
  else
    # 32-bit Java
    AGENT_PATH="$_YH_/bin/linux-x86-32/libyjpagent.so"
  fi
elif [ `uname` = 'Darwin' ] ; then
  # Mac OS X
  AGENT_PATH="$_YH_/bin/mac/libyjpagent.jnilib"
elif [ `uname` = 'SunOS' ] ; then
  # Solaris:
  # We suppose that JVM is 32-bit by default.
  # Change "32" with "64" in the path to use with 64-bit Java.
  if [ "`uname -a | grep sparc`" ] ; then
    AGENT_PATH="$_YH_/bin/solaris-sparc-32/libyjpagent.so"
  elif [ "`uname -a | grep i386`" ] ; then
    AGENT_PATH="$_YH_/bin/solaris-x86-32/libyjpagent.so"
  else
    echo "Unsupported processor architecture"
    exit
  fi
elif [ `uname` = 'FreeBSD' ] ; then
  if [ "`uname -a | grep amd64`" ] ; then
    AGENT_PATH="$_YH_/bin/freebsd-x86-64/libyjpagent.so"
  elif [ "`uname -a | grep i386`" ] ; then
    AGENT_PATH="$_YH_/bin/freebsd-x86-32/libyjpagent.so"
  else
    echo "Unsupported processor architecture"
    exit
  fi
elif [ `uname` = 'HP-UX' ] ; then
  # On HP-UX, JVM is 32-bit by default.
  # Change "32" with "64" in the path to use with 64-bit Java.
  AGENT_PATH="$_YH_/bin/hpux-ia64-32/libyjpagent.so"
else
  echo "Unsupported platform: `uname`"
  exit
fi

echo "Using Java: $JAVA_EXE"
echo "Using agent: $AGENT_PATH"

$JAVA_EXE "-agentpath:$AGENT_PATH" -classpath "$_SAMPLE_DIR_/classes" com.yourkit.examples.MyMainFrame
